pub struct StreamingDecoder { /* private fields */ }Expand description
GIF decoder which emits low-level events for items in the GIF file
To just get GIF frames, use crate::Decoder instead.
Implementations
Sourceimpl StreamingDecoder
impl StreamingDecoder
Sourcepub fn update(
&mut self,
buf: &[u8],
write_into: &mut OutputBuffer<'_>,
) -> Result<(usize, Decoded), DecodingError>
pub fn update( &mut self, buf: &[u8], write_into: &mut OutputBuffer<'_>, ) -> Result<(usize, Decoded), DecodingError>
Updates the internal state of the decoder.
Returns the number of bytes consumed from the input buffer and the last decoding result.
Sourcepub fn last_ext_sub_block(&mut self) -> &[u8] ⓘ
pub fn last_ext_sub_block(&mut self) -> &[u8] ⓘ
Data of the last extension sub block that has been decoded. You need to concatenate all subblocks together to get the overall block content.
Sourcepub fn current_frame_mut(&mut self) -> &mut Frame<'static>
pub fn current_frame_mut(&mut self) -> &mut Frame<'static>
Current frame info as a mutable ref.
Sourcepub fn current_frame(&self) -> &Frame<'static>
pub fn current_frame(&self) -> &Frame<'static>
Current frame info as a ref.